## dbt-spark 1.9.2 - March 07, 2025

### Fixes

- Stop adding aliases to render_limited output for --empty ([#474](https://github.com/dbt-labs/dbt-adapters/issues/474))

### Under the Hood

- Move from setup.py to pyproject.toml and to hatch as a dev tool ([#1150](https://github.com/dbt-labs/dbt-adapters/issues/1150))

### Contributors
- [@anaghshineh](https://github.com/anaghshineh) ([#474](https://github.com/dbt-labs/dbt-adapters/issues/474))
